@@ -27,9 +27,12 @@ CINDER_CLIENT_OPTS = [
                help='Version of Cinder API to use in cinderclient.'),
     cfg.StrOpt('endpoint_type',
                default='publicURL',
-               help='Type of endpoint to use in cinderclient.'
-                    'Supported values: internalURL, publicURL, adminURL'
-                    'The default is publicURL.')]
+               help='Type of endpoint to use in cinderclient. '
+                    'Supported values: internalURL, publicURL, adminURL. '
+                    'The default is publicURL.'),
+    cfg.StrOpt('region_name',
+               help='Region in Identity service catalog to use for '
+                    'communication with the OpenStack service.')]
 
 
 def register_opts(conf):
@@ -38,4 +41,4 @@ def register_opts(conf):
 
 
 def list_opts():
-    return [('cinder_client', CINDER_CLIENT_OPTS)]
+    return [(cinder_client, CINDER_CLIENT_OPTS)]
