@@ -21,7 +21,6 @@ from lxml import etree
 import networkx as nx
 from oslo_concurrency import lockutils
 from oslo_log import log
-import six
 
 from watcher._i18n import _
 from watcher.common import exception
@@ -87,14 +86,15 @@ class ModelRoot(nx.DiGraph, base.Model):
     def map_instance(self, instance, node):
         """Map a newly created instance to a node
 
-        :param instance: :py:class:`~.Instance` object or instance UUID
-        :type instance: str or :py:class:`~.Instance`
-        :param node: :py:class:`~.ComputeNode` object or node UUID
-        :type node: str or :py:class:`~.Instance`
+        :param instance: :py:class:`~.instance.Instance` object or instance
+           UUID
+        :type instance: str or :py:class:`~.instance.Instance`
+        :param node: :py:class:`~.node.ComputeNode` object or node UUID
+        :type node: str or :py:class:`~.instance.Instance`
         """
-        if isinstance(instance, six.string_types):
+        if isinstance(instance, str):
             instance = self.get_instance_by_uuid(instance)
-        if isinstance(node, six.string_types):
+        if isinstance(node, str):
             node = self.get_node_by_uuid(node)
         self.assert_node(node)
         self.assert_instance(instance)
@@ -103,9 +103,9 @@ class ModelRoot(nx.DiGraph, base.Model):
 
     @lockutils.synchronized("model_root")
     def unmap_instance(self, instance, node):
-        if isinstance(instance, six.string_types):
+        if isinstance(instance, str):
             instance = self.get_instance_by_uuid(instance)
-        if isinstance(node, six.string_types):
+        if isinstance(node, str):
             node = self.get_node_by_uuid(node)
 
         self.remove_edge(instance.uuid, node.uuid)
@@ -148,6 +148,19 @@ class ModelRoot(nx.DiGraph, base.Model):
         except exception.ComputeResourceNotFound:
             raise exception.ComputeNodeNotFound(name=uuid)
 
+    @lockutils.synchronized("model_root")
+    def get_node_by_name(self, name):
+        try:
+            node_list = [cn['attr'] for uuid, cn in self.nodes(data=True)
+                         if (isinstance(cn['attr'], element.ComputeNode) and
+                         cn['attr']['hostname'] == name)]
+            if node_list:
+                return node_list[0]
+            else:
+                raise exception.ComputeResourceNotFound
+        except exception.ComputeResourceNotFound:
+            raise exception.ComputeNodeNotFound(name=name)
+
     @lockutils.synchronized("model_root")
     def get_instance_by_uuid(self, uuid):
         try:
@@ -157,7 +170,7 @@ class ModelRoot(nx.DiGraph, base.Model):
 
     def _get_by_uuid(self, uuid):
         try:
-            return self.node[uuid]['attr']
+            return self.nodes[uuid]['attr']
         except Exception as exc:
             LOG.exception(exc)
             raise exception.ComputeResourceNotFound(name=uuid)
@@ -169,7 +182,7 @@ class ModelRoot(nx.DiGraph, base.Model):
             node = self._get_by_uuid(node_uuid)
             if isinstance(node, element.ComputeNode):
                 return node
-        raise exception.ComputeNodeNotFound(name=instance_uuid)
+        raise exception.InstanceNotMapped(uuid=instance_uuid)
 
     @lockutils.synchronized("model_root")
     def get_all_instances(self):
@@ -187,6 +200,25 @@ class ModelRoot(nx.DiGraph, base.Model):
 
         return node_instances
 
+    def get_node_used_resources(self, node):
+        vcpu_used = 0
+        memory_used = 0
+        disk_used = 0
+        for instance in self.get_node_instances(node):
+            vcpu_used += instance.vcpus
+            memory_used += instance.memory
+            disk_used += instance.disk
+
+        return dict(vcpu=vcpu_used, memory=memory_used, disk=disk_used)
+
+    def get_node_free_resources(self, node):
+        resources_used = self.get_node_used_resources(node)
+        vcpu_free = node.vcpu_capacity-resources_used.get('vcpu')
+        memory_free = node.memory_mb_capacity-resources_used.get('memory')
+        disk_free = node.disk_gb_capacity-resources_used.get('disk')
+
+        return dict(vcpu=vcpu_free, memory=memory_free, disk=disk_free)
+
     def to_string(self):
         return self.to_xml()
 
@@ -210,11 +242,33 @@ class ModelRoot(nx.DiGraph, base.Model):
                                key=lambda inst: inst.uuid):
             try:
                 self.get_node_by_instance_uuid(instance.uuid)
-            except (exception.InstanceNotFound, exception.ComputeNodeNotFound):
+            except exception.ComputeResourceNotFound:
                 root.append(instance.as_xml_element())
 
         return etree.tostring(root, pretty_print=True).decode('utf-8')
 
+    def to_list(self):
+        ret_list = []
+        for cn in sorted(self.get_all_compute_nodes().values(),
+                         key=lambda cn: cn.uuid):
+            in_dict = {}
+            for field in cn.fields:
+                new_name = "node_"+str(field)
+                in_dict[new_name] = cn[field]
+            node_instances = self.get_node_instances(cn)
+            if not node_instances:
+                deep_in_dict = in_dict.copy()
+                ret_list.append(deep_in_dict)
+                continue
+            for instance in sorted(node_instances, key=lambda x: x.uuid):
+                for field in instance.fields:
+                    new_name = "server_"+str(field)
+                    in_dict[new_name] = instance[field]
+                if in_dict != {}:
+                    deep_in_dict = in_dict.copy()
+                    ret_list.append(deep_in_dict)
+        return ret_list
+
     @classmethod
     def from_xml(cls, data):
         model = cls()
@@ -309,12 +363,12 @@ class StorageModelRoot(nx.DiGraph, base.Model):
     def map_pool(self, pool, node):
         """Map a newly created pool to a node
 
-        :param pool: :py:class:`~.Pool` object or pool name
-        :param node: :py:class:`~.StorageNode` object or node host
+        :param pool: :py:class:`~.node.Pool` object or pool name
+        :param node: :py:class:`~.node.StorageNode` object or node host
         """
-        if isinstance(pool, six.string_types):
+        if isinstance(pool, str):
             pool = self.get_pool_by_pool_name(pool)
-        if isinstance(node, six.string_types):
+        if isinstance(node, str):
             node = self.get_node_by_name(node)
         self.assert_node(node)
         self.assert_pool(pool)
@@ -325,12 +379,12 @@ class StorageModelRoot(nx.DiGraph, base.Model):
     def unmap_pool(self, pool, node):
         """Unmap a pool from a node
 
-        :param pool: :py:class:`~.Pool` object or pool name
-        :param node: :py:class:`~.StorageNode` object or node name
+        :param pool: :py:class:`~.node.Pool` object or pool name
+        :param node: :py:class:`~.node.StorageNode` object or node name
         """
-        if isinstance(pool, six.string_types):
+        if isinstance(pool, str):
             pool = self.get_pool_by_pool_name(pool)
-        if isinstance(node, six.string_types):
+        if isinstance(node, str):
             node = self.get_node_by_name(node)
 
         self.remove_edge(pool.name, node.host)
@@ -353,12 +407,12 @@ class StorageModelRoot(nx.DiGraph, base.Model):
     def map_volume(self, volume, pool):
         """Map a newly created volume to a pool
 
-        :param volume: :py:class:`~.Volume` object or volume UUID
-        :param pool: :py:class:`~.Pool` object or pool name
+        :param volume: :py:class:`~.volume.Volume` object or volume UUID
+        :param pool: :py:class:`~.node.Pool` object or pool name
         """
-        if isinstance(volume, six.string_types):
+        if isinstance(volume, str):
             volume = self.get_volume_by_uuid(volume)
-        if isinstance(pool, six.string_types):
+        if isinstance(pool, str):
             pool = self.get_pool_by_pool_name(pool)
         self.assert_pool(pool)
         self.assert_volume(volume)
@@ -369,12 +423,12 @@ class StorageModelRoot(nx.DiGraph, base.Model):
     def unmap_volume(self, volume, pool):
         """Unmap a volume from a pool
 
-        :param volume: :py:class:`~.Volume` object or volume UUID
-        :param pool: :py:class:`~.Pool` object or pool name
+        :param volume: :py:class:`~.volume.Volume` object or volume UUID
+        :param pool: :py:class:`~.node.Pool` object or pool name
         """
-        if isinstance(volume, six.string_types):
+        if isinstance(volume, str):
             volume = self.get_volume_by_uuid(volume)
-        if isinstance(pool, six.string_types):
+        if isinstance(pool, str):
             pool = self.get_pool_by_pool_name(pool)
 
         self.remove_edge(volume.uuid, pool.name)
@@ -390,10 +444,6 @@ class StorageModelRoot(nx.DiGraph, base.Model):
 
     @lockutils.synchronized("storage_model")
     def get_node_by_name(self, name):
-        """Get a node by node name
-
-        :param node: :py:class:`~.StorageNode` object or node name
-        """
         try:
             return self._get_by_name(name.split("#")[0])
         except exception.StorageResourceNotFound:
@@ -415,14 +465,14 @@ class StorageModelRoot(nx.DiGraph, base.Model):
 
     def _get_by_uuid(self, uuid):
         try:
-            return self.node[uuid]['attr']
+            return self.nodes[uuid]['attr']
         except Exception as exc:
             LOG.exception(exc)
             raise exception.StorageResourceNotFound(name=uuid)
 
     def _get_by_name(self, name):
         try:
-            return self.node[name]['attr']
+            return self.nodes[name]['attr']
         except Exception as exc:
             LOG.exception(exc)
             raise exception.StorageResourceNotFound(name=name)
@@ -597,7 +647,7 @@ class BaremetalModelRoot(nx.DiGraph, base.Model):
 
     def _get_by_uuid(self, uuid):
         try:
-            return self.node[uuid]['attr']
+            return self.nodes[uuid]['attr']
         except Exception as exc:
             LOG.exception(exc)
         raise exception.BaremetalResourceNotFound(name=uuid)
