@@ -21,7 +21,6 @@ from oslo_config import cfg
 from oslo_log import log
 
 from watcher._i18n import _
-from watcher.common import exception
 from watcher.decision_engine.model import element
 from watcher.decision_engine.strategy.strategies import base
 
@@ -49,24 +48,8 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
     that live migration is possible on your OpenStack cluster.
     """
 
-    HOST_CPU_USAGE_METRIC_NAME = 'compute.node.cpu.percent'
-    INSTANCE_CPU_USAGE_METRIC_NAME = 'cpu_util'
-
     DATASOURCE_METRICS = ['host_cpu_usage', 'instance_cpu_usage']
 
-    METRIC_NAMES = dict(
-        ceilometer=dict(
-            host_cpu_usage='compute.node.cpu.percent',
-            instance_cpu_usage='cpu_util'),
-        monasca=dict(
-            host_cpu_usage='cpu.percent',
-            instance_cpu_usage='vm.cpu.utilization_perc'),
-        gnocchi=dict(
-            host_cpu_usage='compute.node.cpu.percent',
-            instance_cpu_usage='cpu_util'),
-    )
-
-    MIGRATION = "migrate"
     CHANGE_NOVA_SERVICE_STATE = "change_nova_service_state"
 
     def __init__(self, config, osc=None):
@@ -112,8 +95,12 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
     @property
     def aggregation_method(self):
         return self.input_parameters.get(
-            'aggregation_method',
-            {"instance": 'mean', "node": 'mean'})
+            'aggregation_method', {
+                "instance": 'mean',
+                "compute_node": 'mean',
+                "node": ''
+            }
+        )
 
     @classmethod
     def get_display_name(cls):
@@ -161,31 +148,33 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
                             "type": "string",
                             "default": 'mean'
                         },
-                        "node": {
+                        "compute_node": {
                             "type": "string",
                             "default": 'mean'
                         },
+                        "node": {
+                            "type": "string",
+                            # node is deprecated
+                            "default": ''
+                        },
                     },
-                    "default": {"instance": 'mean', "node": 'mean'}
+                    "default": {
+                        "instance": 'mean',
+                        "compute_node": 'mean',
+                        # node is deprecated
+                        "node": '',
+                    }
                 },
             },
         }
 
     @classmethod
     def get_config_opts(cls):
-        return [
-            cfg.ListOpt(
-                "datasources",
-                help="Datasources to use in order to query the needed metrics."
-                     " If one of strategy metric isn't available in the first"
-                     " datasource, the next datasource will be chosen.",
-                item_type=cfg.types.String(choices=['gnocchi', 'ceilometer',
-                                                    'monasca']),
-                default=['gnocchi', 'ceilometer', 'monasca']),
+        return super(BasicConsolidation, cls).get_config_opts() + [
             cfg.BoolOpt(
-                "check_optimize_metadata",
-                help="Check optimize metadata field in instance before "
-                     "migration",
+                'check_optimize_metadata',
+                help='Check optimize metadata field in instance before'
+                     ' migration',
                 default=False),
         ]
 
@@ -212,19 +201,13 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
         LOG.debug('Migrate instance %s from %s to  %s',
                   instance_to_migrate, source_node, destination_node)
 
-        total_cores = 0
-        total_disk = 0
-        total_mem = 0
-        for instance in self.compute_model.get_node_instances(
-                destination_node):
-            total_cores += instance.vcpus
-            total_disk += instance.disk
-            total_mem += instance.memory
+        used_resources = self.compute_model.get_node_used_resources(
+            destination_node)
 
         # capacity requested by the compute node
-        total_cores += instance_to_migrate.vcpus
-        total_disk += instance_to_migrate.disk
-        total_mem += instance_to_migrate.memory
+        total_cores = used_resources['vcpu'] + instance_to_migrate.vcpus
+        total_disk = used_resources['disk'] + instance_to_migrate.disk
+        total_mem = used_resources['memory'] + instance_to_migrate.memory
 
         return self.check_threshold(destination_node, total_cores, total_disk,
                                     total_mem)
@@ -243,9 +226,9 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
         :param total_mem: total memory used by the virtual machine
         :return: True if the threshold is not exceed
         """
-        cpu_capacity = destination_node.vcpus
-        disk_capacity = destination_node.disk
-        memory_capacity = destination_node.memory
+        cpu_capacity = destination_node.vcpu_capacity
+        disk_capacity = destination_node.disk_gb_capacity
+        memory_capacity = destination_node.memory_mb_capacity
 
         return (cpu_capacity >= total_cores * self.threshold_cores and
                 disk_capacity >= total_disk * self.threshold_disk and
@@ -281,16 +264,15 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
         # TODO(jed): take in account weight
         return (score_cores + score_disk + score_memory) / 3
 
-    def get_node_cpu_usage(self, node):
-        resource_id = "%s_%s" % (node.uuid, node.hostname)
+    def get_compute_node_cpu_usage(self, compute_node):
         return self.datasource_backend.get_host_cpu_usage(
-            resource_id, self.period, self.aggregation_method['node'],
-            granularity=self.granularity)
+            compute_node, self.period, self.aggregation_method['compute_node'],
+            self.granularity)
 
     def get_instance_cpu_usage(self, instance):
         return self.datasource_backend.get_instance_cpu_usage(
-            instance.uuid, self.period, self.aggregation_method['instance'],
-            granularity=self.granularity)
+            instance, self.period, self.aggregation_method['instance'],
+            self.granularity)
 
     def calculate_score_node(self, node):
         """Calculate the score that represent the utilization level
@@ -299,7 +281,7 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
         :return: Score for the given compute node
         :rtype: float
         """
-        host_avg_cpu_util = self.get_node_cpu_usage(node)
+        host_avg_cpu_util = self.get_compute_node_cpu_usage(node)
 
         if host_avg_cpu_util is None:
             resource_id = "%s_%s" % (node.uuid, node.hostname)
@@ -307,8 +289,7 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
                 "No values returned by %(resource_id)s "
                 "for %(metric_name)s", dict(
                     resource_id=resource_id,
-                    metric_name=self.METRIC_NAMES[
-                        self.config.datasource]['host_cpu_usage']))
+                    metric_name='host_cpu_usage'))
             host_avg_cpu_util = 100
 
         total_cores_used = node.vcpus * (host_avg_cpu_util / 100.0)
@@ -327,31 +308,19 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
                 "No values returned by %(resource_id)s "
                 "for %(metric_name)s", dict(
                     resource_id=instance.uuid,
-                    metric_name=self.METRIC_NAMES[
-                        self.config.datasource]['instance_cpu_usage']))
+                    metric_name='instance_cpu_usage'))
             instance_cpu_utilization = 100
 
         total_cores_used = instance.vcpus * (instance_cpu_utilization / 100.0)
 
         return self.calculate_weight(instance, total_cores_used, 0, 0)
 
-    def add_action_disable_node(self, resource_id):
+    def add_action_disable_node(self, node):
         parameters = {'state': element.ServiceState.DISABLED.value,
-                      'disabled_reason': self.REASON_FOR_DISABLE}
+                      'disabled_reason': self.REASON_FOR_DISABLE,
+                      'resource_name': node.hostname}
         self.solution.add_action(action_type=self.CHANGE_NOVA_SERVICE_STATE,
-                                 resource_id=resource_id,
-                                 input_parameters=parameters)
-
-    def add_migration(self,
-                      resource_id,
-                      migration_type,
-                      source_node,
-                      destination_node):
-        parameters = {'migration_type': migration_type,
-                      'source_node': source_node,
-                      'destination_node': destination_node}
-        self.solution.add_action(action_type=self.MIGRATION,
-                                 resource_id=resource_id,
+                                 resource_id=node.uuid,
                                  input_parameters=parameters)
 
     def compute_score_of_nodes(self):
@@ -388,12 +357,12 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
         """Create migration VM"""
         if self.compute_model.migrate_instance(
                 mig_instance, mig_source_node, mig_destination_node):
-            self.add_migration(mig_instance.uuid, 'live',
-                               mig_source_node.uuid,
-                               mig_destination_node.uuid)
+            self.add_action_migrate(mig_instance, 'live',
+                                    mig_source_node,
+                                    mig_destination_node)
 
         if len(self.compute_model.get_node_instances(mig_source_node)) == 0:
-            self.add_action_disable_node(mig_source_node.uuid)
+            self.add_action_disable_node(mig_source_node)
             self.number_of_released_nodes += 1
 
     def calculate_num_migrations(self, sorted_instances, node_to_release,
@@ -429,20 +398,16 @@ class BasicConsolidation(base.ServerConsolidationBaseStrategy):
             return unsuccessful_migration + 1
 
     def pre_execute(self):
-        LOG.info("Initializing Server Consolidation")
+        self._pre_execute()
 
-        if not self.compute_model:
-            raise exception.ClusterStateNotDefined()
+        # backwards compatibility for node parameter.
+        if self.aggregation_method['node'] != '':
+            LOG.warning('Parameter node has been renamed to compute_node and '
+                        'will be removed in next release.')
+            self.aggregation_method['compute_node'] = \
+                self.aggregation_method['node']
 
-        if len(self.get_available_compute_nodes()) == 0:
-            raise exception.ClusterEmpty()
-
-        if self.compute_model.stale:
-            raise exception.ClusterStateStale()
-
-        LOG.debug(self.compute_model.to_string())
-
-    def do_execute(self):
+    def do_execute(self, audit=None):
         unsuccessful_migration = 0
 
         scores = self.compute_score_of_nodes()
