@@ -13,7 +13,6 @@
 #
 
 from dateutil.parser import parse
-import six
 
 from oslo_log import log
 
@@ -21,7 +20,6 @@ from cinderclient.v2.volumes import Volume
 from novaclient.v2.servers import Server
 from watcher._i18n import _
 from watcher.common import cinder_helper
-from watcher.common import exception as wexc
 from watcher.common import nova_helper
 from watcher.decision_engine.model import element
 from watcher.decision_engine.strategy.strategies import base
@@ -89,7 +87,7 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
                                 "type": "string"
                             },
                             "dst_node": {
-                                "description": "Compute node to which"
+                                "description": "Compute node to which "
                                                "instances migrate",
                                 "type": "string"
                             }
@@ -267,22 +265,10 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
                 cn.status in default_node_scope}
 
     def pre_execute(self):
-        """Pre-execution phase
-
-        This can be used to fetch some pre-requisites or data.
-        """
-        LOG.info("Initializing zone migration Strategy")
-
-        if len(self.get_available_compute_nodes()) == 0:
-            raise wexc.ComputeClusterEmpty()
-
-        if len(self.get_available_storage_nodes()) == 0:
-            raise wexc.StorageClusterEmpty()
-
-        LOG.debug(self.compute_model.to_string())
+        self._pre_execute()
         LOG.debug(self.storage_model.to_string())
 
-    def do_execute(self):
+    def do_execute(self, audit=None):
         """Strategy execution phase
 
         """
@@ -295,7 +281,7 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
         action_counter = ActionCounter(total_limit,
                                        per_pool_limit, per_node_limit)
 
-        for k, targets in six.iteritems(filtered_targets):
+        for k, targets in iter(filtered_targets.items()):
             if k == VOLUME:
                 self.volumes_migration(targets, action_counter)
             elif k == INSTANCE:
@@ -420,11 +406,11 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
 
             if self.is_available(volume):
                 if src_type == dst_type:
-                    self._volume_migrate(volume.id, dst_pool)
+                    self._volume_migrate(volume, dst_pool)
                 else:
-                    self._volume_retype(volume.id, dst_type)
+                    self._volume_retype(volume, dst_type)
             elif self.is_in_use(volume):
-                self._volume_update(volume.id, dst_type)
+                self._volume_update(volume, dst_type)
 
                 # if with_attached_volume is True, migrate attaching instances
                 if self.with_attached_volume:
@@ -450,56 +436,61 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
 
             dst_node = self.get_dst_node(src_node)
             if self.is_live(instance):
-                self._live_migration(instance.id, src_node, dst_node)
+                self._live_migration(instance, src_node, dst_node)
             elif self.is_cold(instance):
-                self._cold_migration(instance.id, src_node, dst_node)
+                self._cold_migration(instance, src_node, dst_node)
 
             action_counter.add_node(src_node)
 
-    def _live_migration(self, resource_id, src_node, dst_node):
+    def _live_migration(self, instance, src_node, dst_node):
         parameters = {"migration_type": "live",
                       "destination_node": dst_node,
-                      "source_node": src_node}
+                      "source_node": src_node,
+                      "resource_name": instance.name}
         self.solution.add_action(
             action_type="migrate",
-            resource_id=resource_id,
+            resource_id=instance.id,
             input_parameters=parameters)
         self.planned_live_count += 1
 
-    def _cold_migration(self, resource_id, src_node, dst_node):
+    def _cold_migration(self, instance, src_node, dst_node):
         parameters = {"migration_type": "cold",
                       "destination_node": dst_node,
-                      "source_node": src_node}
+                      "source_node": src_node,
+                      "resource_name": instance.name}
         self.solution.add_action(
             action_type="migrate",
-            resource_id=resource_id,
+            resource_id=instance.id,
             input_parameters=parameters)
         self.planned_cold_count += 1
 
-    def _volume_update(self, resource_id, dst_type):
+    def _volume_update(self, volume, dst_type):
         parameters = {"migration_type": "swap",
-                      "destination_type": dst_type}
+                      "destination_type": dst_type,
+                      "resource_name": volume.name}
         self.solution.add_action(
             action_type="volume_migrate",
-            resource_id=resource_id,
+            resource_id=volume.id,
             input_parameters=parameters)
         self.planned_volume_update_count += 1
 
-    def _volume_migrate(self, resource_id, dst_pool):
+    def _volume_migrate(self, volume, dst_pool):
         parameters = {"migration_type": "migrate",
-                      "destination_node": dst_pool}
+                      "destination_node": dst_pool,
+                      "resource_name": volume.name}
         self.solution.add_action(
             action_type="volume_migrate",
-            resource_id=resource_id,
+            resource_id=volume.id,
             input_parameters=parameters)
         self.planned_volume_count += 1
 
-    def _volume_retype(self, resource_id, dst_type):
+    def _volume_retype(self, volume, dst_type):
         parameters = {"migration_type": "retype",
-                      "destination_type": dst_type}
+                      "destination_type": dst_type,
+                      "resource_name": volume.name}
         self.solution.add_action(
             action_type="volume_migrate",
-            resource_id=resource_id,
+            resource_id=volume.id,
             input_parameters=parameters)
         self.planned_volume_count += 1
 
@@ -535,8 +526,8 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
             return None
 
         return [i for i in self.nova.get_instance_list()
-                if getattr(i, 'OS-EXT-SRV-ATTR:host') in src_node_list
-                and self.compute_model.get_instance_by_uuid(i.id)]
+                if getattr(i, 'OS-EXT-SRV-ATTR:host') in src_node_list and
+                self.compute_model.get_instance_by_uuid(i.id)]
 
     def get_volumes(self):
         """Get migrate target volumes
@@ -547,8 +538,8 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
         src_pool_list = self.get_src_pool_list()
 
         return [i for i in self.cinder.get_volume_list()
-                if getattr(i, 'os-vol-host-attr:host') in src_pool_list
-                and self.storage_model.get_volume_by_uuid(i.id)]
+                if getattr(i, 'os-vol-host-attr:host') in src_pool_list and
+                self.storage_model.get_volume_by_uuid(i.id)]
 
     def filtered_targets(self):
         """Filter targets
@@ -588,7 +579,7 @@ class ZoneMigration(base.ZoneMigrationBaseStrategy):
         filter_list = []
         priority_filter_map = self.get_priority_filter_map()
 
-        for k, v in six.iteritems(self.priority):
+        for k, v in iter(self.priority.items()):
             if k in priority_filter_map:
                 filter_list.append(priority_filter_map[k](v))
 
@@ -718,7 +709,7 @@ class BaseFilter(object):
             return {}
 
         for cond in list(reversed(self.condition)):
-            for k, v in six.iteritems(targets):
+            for k, v in iter(targets.items()):
                 if not self.is_allowed(k):
                     continue
                 LOG.debug("filter:%s with the key: %s", cond, k)
