@@ -14,9 +14,8 @@
 
 """Tests for the Pecan API hooks."""
 
-from __future__ import unicode_literals
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 import oslo_messaging as messaging
 from oslo_serialization import jsonutils
@@ -144,8 +143,8 @@ class TestNoExceptionTracebackHook(base.FunctionalTest):
         # rare thing (happens due to wrong deserialization settings etc.)
         # we don't care about this garbage.
         expected_msg = ("Remote error: %s %s"
-                        % (test_exc_type, self.MSG_WITHOUT_TRACE)
-                        + ("\n[u'" if six.PY2 else "\n['"))
+                        % (test_exc_type, self.MSG_WITHOUT_TRACE) +
+                        ("\n[u'" if six.PY2 else "\n['"))
         actual_msg = jsonutils.loads(
             response.json['error_message'])['faultstring']
         self.assertEqual(expected_msg, actual_msg)
@@ -222,7 +221,6 @@ class TestContextHook(base.FunctionalTest):
             user_id=headers['X-User-Id'],
             domain_id=headers['X-User-Domain-Id'],
             domain_name=headers['X-User-Domain-Name'],
-            auth_url=cfg.CONF.keystone_authtoken.www_authenticate_uri,
             project=headers['X-Project-Name'],
             project_id=headers['X-Project-Id'],
             show_deleted=None,
@@ -243,7 +241,6 @@ class TestContextHook(base.FunctionalTest):
             user_id=headers['X-User-Id'],
             domain_id=headers['X-User-Domain-Id'],
             domain_name=headers['X-User-Domain-Name'],
-            auth_url=cfg.CONF.keystone_authtoken.www_authenticate_uri,
             project=headers['X-Project-Name'],
             project_id=headers['X-Project-Id'],
             show_deleted=None,
@@ -265,7 +262,6 @@ class TestContextHook(base.FunctionalTest):
             user_id=headers['X-User-Id'],
             domain_id=headers['X-User-Domain-Id'],
             domain_name=headers['X-User-Domain-Name'],
-            auth_url=cfg.CONF.keystone_authtoken.www_authenticate_uri,
             project=headers['X-Project-Name'],
             project_id=headers['X-Project-Id'],
             show_deleted=None,
