@@ -12,12 +12,13 @@
 
 import datetime
 import itertools
-import mock
+from unittest import mock
+from urllib import parse as urlparse
 
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-from six.moves.urllib import parse as urlparse
+import webtest.app as webtest_app
 from wsme import types as wtypes
 
 from watcher.api.controllers.v1 import audit_template as api_audit_template
@@ -32,14 +33,12 @@ from watcher.tests.objects import utils as obj_utils
 
 
 def post_get_test_audit_template(**kw):
-    audit_template = api_utils.audit_template_post_data(**kw)
     goal = db_utils.get_test_goal()
     strategy = db_utils.get_test_strategy(goal_id=goal['id'])
-    del audit_template['uuid']
-    del audit_template['goal_id']
-    del audit_template['strategy_id']
-    audit_template['goal'] = kw.get('goal', goal['uuid'])
-    audit_template['strategy'] = kw.get('strategy', strategy['uuid'])
+    kw['goal'] = kw.get('goal', goal['uuid'])
+    kw['strategy'] = kw.get('strategy', strategy['uuid'])
+    kw['scope'] = kw.get('scope', [])
+    audit_template = api_utils.audit_template_post_data(**kw)
     return audit_template
 
 
@@ -57,20 +56,16 @@ class FunctionalTestWithSetup(api_base.FunctionalTest):
 
     def setUp(self):
         super(FunctionalTestWithSetup, self).setUp()
-        self.fake_goal1 = obj_utils.get_test_goal(
+        self.fake_goal1 = obj_utils.create_test_goal(
             self.context, id=1, uuid=utils.generate_uuid(), name="dummy_1")
-        self.fake_goal2 = obj_utils.get_test_goal(
+        self.fake_goal2 = obj_utils.create_test_goal(
             self.context, id=2, uuid=utils.generate_uuid(), name="dummy_2")
-        self.fake_goal1.create()
-        self.fake_goal2.create()
-        self.fake_strategy1 = obj_utils.get_test_strategy(
+        self.fake_strategy1 = obj_utils.create_test_strategy(
             self.context, id=1, uuid=utils.generate_uuid(), name="strategy_1",
             goal_id=self.fake_goal1.id)
-        self.fake_strategy2 = obj_utils.get_test_strategy(
+        self.fake_strategy2 = obj_utils.create_test_strategy(
             self.context, id=2, uuid=utils.generate_uuid(), name="strategy_2",
             goal_id=self.fake_goal2.id)
-        self.fake_strategy1.create()
-        self.fake_strategy2.create()
 
 
 class TestListAuditTemplate(FunctionalTestWithSetup):
@@ -81,8 +76,7 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
 
     def _assert_audit_template_fields(self, audit_template):
         audit_template_fields = ['name', 'goal_uuid', 'goal_name',
-                                 'strategy_uuid', 'strategy_name',
-                                 'host_aggregate']
+                                 'strategy_uuid', 'strategy_name']
         for field in audit_template_fields:
             self.assertIn(field, audit_template)
 
@@ -237,8 +231,7 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
         self.assertIn(next_marker, response['next'])
 
     def test_collection_links_default_limit(self):
-        cfg.CONF.set_override('max_limit', 3, 'api',
-                              enforce_type=True)
+        cfg.CONF.set_override('max_limit', 3, 'api')
         for id_ in range(5):
             obj_utils.create_test_audit_template(
                 self.context, id=id_, uuid=utils.generate_uuid(),
@@ -301,11 +294,56 @@ class TestListAuditTemplate(FunctionalTestWithSetup):
             '/audit_templates?strategy=%s' % self.fake_strategy2.name)
         self.assertEqual(2, len(response['audit_templates']))
 
+    def test_many_with_sort_key_name(self):
+        audit_template_list = []
+        for id_ in range(1, 6):
+            audit_template = obj_utils.create_test_audit_template(
+                self.context, id=id_, uuid=utils.generate_uuid(),
+                name='My Audit Template {0}'.format(id_))
+            audit_template_list.append(audit_template)
+
+        response = self.get_json('/audit_templates?sort_key=%s' % 'name')
+
+        names = [s['name'] for s in response['audit_templates']]
+
+        self.assertEqual(
+            sorted([at.name for at in audit_template_list]),
+            names)
+
+    def test_many_with_sort_key_goal_name(self):
+        goal_names_list = []
+        for id_, goal_id in enumerate(itertools.chain.from_iterable([
+                itertools.repeat(self.fake_goal1.id, 3),
+                itertools.repeat(self.fake_goal2.id, 2)]), 1):
+            audit_template = obj_utils.create_test_audit_template(
+                self.context, id=id_, uuid=utils.generate_uuid(),
+                name='My Audit Template {0}'.format(id_),
+                goal_id=goal_id)
+            goal_names_list.append(audit_template.goal.name)
+
+        for direction in ['asc', 'desc']:
+            response = self.get_json(
+                '/audit_templates?sort_key={0}&sort_dir={1}'
+                .format('goal_name', direction))
+
+            goal_names = [s['goal_name'] for s in response['audit_templates']]
+
+            self.assertEqual(
+                sorted(goal_names_list, reverse=(direction == 'desc')),
+                goal_names)
+
+    def test_sort_key_validation(self):
+        response = self.get_json(
+            '/audit_templates?sort_key=%s' % 'goal_bad_name',
+            expect_errors=True)
+        self.assertEqual(400, response.status_int)
+
 
 class TestPatch(FunctionalTestWithSetup):
 
     def setUp(self):
         super(TestPatch, self).setUp()
+        obj_utils.create_test_goal(self.context)
         self.audit_template = obj_utils.create_test_audit_template(
             self.context, strategy_id=None)
 
@@ -517,6 +555,66 @@ class TestPost(FunctionalTestWithSetup):
             response.json['created_at']).replace(tzinfo=None)
         self.assertEqual(test_time, return_created_at)
 
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_create_audit_template_with_strategy_name(self, mock_utcnow):
+        audit_template_dict = post_get_test_audit_template(
+            goal=self.fake_goal1.uuid,
+            strategy=self.fake_strategy1.name)
+        test_time = datetime.datetime(2000, 1, 1, 0, 0)
+        mock_utcnow.return_value = test_time
+
+        response = self.post_json('/audit_templates', audit_template_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        # Check location header
+        self.assertIsNotNone(response.location)
+        expected_location = \
+            '/v1/audit_templates/%s' % response.json['uuid']
+        self.assertEqual(urlparse.urlparse(response.location).path,
+                         expected_location)
+        self.assertTrue(utils.is_uuid_like(response.json['uuid']))
+        self.assertNotIn('updated_at', response.json.keys)
+        self.assertNotIn('deleted_at', response.json.keys)
+        self.assertEqual(self.fake_goal1.uuid, response.json['goal_uuid'])
+        self.assertEqual(self.fake_strategy1.uuid,
+                         response.json['strategy_uuid'])
+        self.assertEqual(self.fake_strategy1.name,
+                         response.json['strategy_name'])
+        return_created_at = timeutils.parse_isotime(
+            response.json['created_at']).replace(tzinfo=None)
+        self.assertEqual(test_time, return_created_at)
+
+    def test_create_audit_template_validation_with_aggregates(self):
+        scope = [{'compute': [{'host_aggregates': [{'id': '*'}]},
+                              {'availability_zones': [{'name': 'AZ1'},
+                                                      {'name': 'AZ2'}]},
+                              {'exclude': [
+                                  {'instances': [
+                                      {'uuid': 'INSTANCE_1'},
+                                      {'uuid': 'INSTANCE_2'}]},
+                                  {'compute_nodes': [
+                                      {'name': 'Node_1'},
+                                      {'name': 'Node_2'}]},
+                                  {'host_aggregates': [{'id': '*'}]}
+                              ]}
+                              ]
+                  }
+                 ]
+        audit_template_dict = post_get_test_audit_template(
+            goal=self.fake_goal1.uuid,
+            strategy=self.fake_strategy1.uuid, scope=scope)
+        with self.assertRaisesRegex(webtest_app.AppError,
+                                    "be included and excluded together"):
+            self.post_json('/audit_templates', audit_template_dict)
+
+        scope = [{'host_aggregates': [{'id1': '*'}]}]
+        audit_template_dict = post_get_test_audit_template(
+            goal=self.fake_goal1.uuid,
+            strategy=self.fake_strategy1.uuid, scope=scope)
+        response = self.post_json('/audit_templates',
+                                  audit_template_dict, expect_errors=True)
+        self.assertEqual(500, response.status_int)
+
     def test_create_audit_template_does_autogenerate_id(self):
         audit_template_dict = post_get_test_audit_template(
             goal=self.fake_goal1.uuid, strategy=None)
@@ -594,11 +692,32 @@ class TestPost(FunctionalTestWithSetup):
         self.assertEqual(400, response.status_int)
         assert not cn_mock.called
 
+    def test_create_audit_template_with_old_scope(self):
+        scope = [{'host_aggregates': [{'id': '*'}]},
+                 {'availability_zones': [{'name': 'AZ1'},
+                                         {'name': 'AZ2'}]},
+                 {'exclude': [
+                     {'instances': [
+                         {'uuid': 'INSTANCE_1'},
+                         {'uuid': 'INSTANCE_2'}]},
+                     {'compute_nodes': [
+                         {'name': 'Node_1'},
+                         {'name': 'Node_2'}]},
+                 ]}
+                 ]
+        audit_template_dict = post_get_test_audit_template(
+            goal=self.fake_goal1.uuid,
+            strategy=self.fake_strategy1.uuid, scope=scope)
+        response = self.post_json('/audit_templates',
+                                  audit_template_dict)
+        self.assertEqual(201, response.status_int)
+
 
 class TestDelete(api_base.FunctionalTest):
 
     def setUp(self):
         super(TestDelete, self).setUp()
+        obj_utils.create_test_goal(self.context)
         self.audit_template = obj_utils.create_test_audit_template(
             self.context)
 
@@ -657,7 +776,7 @@ class TestDelete(api_base.FunctionalTest):
         self.assertTrue(response.json['error_message'])
 
 
-class TestAuaditTemplatePolicyEnforcement(api_base.FunctionalTest):
+class TestAuditTemplatePolicyEnforcement(api_base.FunctionalTest):
 
     def _common_policy_check(self, rule, func, *arg, **kwarg):
         self.policy.set_rules({
@@ -677,6 +796,7 @@ class TestAuaditTemplatePolicyEnforcement(api_base.FunctionalTest):
             expect_errors=True)
 
     def test_policy_disallow_get_one(self):
+        obj_utils.create_test_goal(self.context)
         audit_template = obj_utils.create_test_audit_template(self.context)
         self._common_policy_check(
             "audit_template:get", self.get_json,
@@ -690,12 +810,13 @@ class TestAuaditTemplatePolicyEnforcement(api_base.FunctionalTest):
             expect_errors=True)
 
     def test_policy_disallow_update(self):
+        obj_utils.create_test_goal(self.context)
         audit_template = obj_utils.create_test_audit_template(self.context)
         self._common_policy_check(
             "audit_template:update", self.patch_json,
             '/audit_templates/%s' % audit_template.uuid,
-            [{'path': '/state', 'value': 'SUBMITTED', 'op': 'replace'}],
-            expect_errors=True)
+            [{'path': '/state', 'value': objects.audit.State.SUCCEEDED,
+              'op': 'replace'}], expect_errors=True)
 
     def test_policy_disallow_create(self):
         fake_goal1 = obj_utils.get_test_goal(
@@ -714,6 +835,7 @@ class TestAuaditTemplatePolicyEnforcement(api_base.FunctionalTest):
             audit_template_dict, expect_errors=True)
 
     def test_policy_disallow_delete(self):
+        obj_utils.create_test_goal(self.context)
         audit_template = obj_utils.create_test_audit_template(self.context)
         self._common_policy_check(
             "audit_template:delete", self.delete,
